@@ -45,7 +45,7 @@ class CBProjectMetaData:
         :param str request_id: UUID
         :param str filename:
             alternative meta data file name, default is
-            Defaults.get_cloud_builder_metadata_file_name()
+            Defaults.get_cloud_builder_meta_project_setup_file_name()
             in Defaults.get_cloud_builder_meta_dir()
 
         :return: yaml dictionary data or empty dict
@@ -55,7 +55,7 @@ class CBProjectMetaData:
         config_data: Dict[str, str] = {}
         config_file = filename or os.path.join(
             package_path, Defaults.get_cloud_builder_meta_dir(),
-            Defaults.get_cloud_builder_metadata_file_name()
+            Defaults.get_cloud_builder_meta_project_setup_file_name()
         )
         if os.path.isfile(config_file):
             with open(config_file, 'r') as config:
